==> jc-1.4.0.tar.gz: polyglot/ext/param/types/MuPClass__5fc.h <==
// public class polyglot.ext.param.types.MuPClass_c

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class d130bd574566704f polyglot_ext_jl_types_TypeObject__5fc
// @dep_class 16b1510ff9395e7b polyglot_ext_param_types_MuPClass__5fc
// @dep_class 1396827e5adf47cf polyglot_ext_param_types_PClass__5fc

// header file dependencies
// @dep_header polyglot_ext_param_types_PClass__5fc

#include "polyglot/ext/param/types/PClass__5fc.h"

#ifndef _JC_polyglot_ext_param_types_MuPClass__5fc_H_
#define _JC_polyglot_ext_param_types_MuPClass__5fc_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_List$object;
struct _jc_polyglot_ext_param_types_Param$object;
struct _jc_polyglot_types_ClassType$object;
struct _jc_polyglot_types_TypeSystem$object;
struct _jc_polyglot_util_Position$object;

// Typedefs
typedef struct _jc_polyglot_ext_param_types_MuPClass__5fc$sub_refs	_jc_polyglot_ext_param_types_MuPClass__5fc$sub_refs;
typedef struct _jc_polyglot_ext_param_types_MuPClass__5fc$sub_nonrefs	_jc_polyglot_ext_param_types_MuPClass__5fc$sub_nonrefs;
typedef struct _jc_polyglot_ext_param_types_MuPClass__5fc$refs	_jc_polyglot_ext_param_types_MuPClass__5fc$refs;
typedef struct _jc_polyglot_ext_param_types_MuPClass__5fc$nonrefs	_jc_polyglot_ext_param_types_MuPClass__5fc$nonrefs;
typedef struct _jc_polyglot_ext_param_types_MuPClass__5fc$object	_jc_polyglot_ext_param_types_MuPClass__5fc$object;

typedef struct _jc_polyglot_ext_param_types_MuPClass__5fc$fields_struct	_jc_polyglot_ext_param_types_MuPClass__5fc$fields_struct;
typedef const struct _jc_polyglot_ext_param_types_MuPClass__5fc$vmethods	_jc_polyglot_ext_param_types_MuPClass__5fc$vmethods;
typedef const struct _jc_polyglot_ext_param_types_MuPClass__5fc$vtable	_jc_polyglot_ext_param_types_MuPClass__5fc$vtable;
typedef const struct _jc_polyglot_ext_param_types_MuPClass__5fc$vtype	_jc_polyglot_ext_param_types_MuPClass__5fc$vtype;

// Class fields structure
struct _jc_polyglot_ext_param_types_MuPClass__5fc$fields_struct {
	struct _jc_java_lang_Class$object	*class__24polyglot__24ext__24param__24types__24Param;
};
extern _jc_polyglot_ext_param_types_MuPClass__5fc$fields_struct _jc_polyglot_ext_param_types_MuPClass__5fc$class_fields;

// Constructors
extern void _jc_polyglot_ext_param_types_MuPClass__5fc$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_polyglot_ext_param_types_MuPClass__5fc$object *);
extern void _jc_polyglot_ext_param_types_MuPClass__5fc$method$_init$964314195388e7c0(_jc_env *, struct _jc_polyglot_ext_param_types_MuPClass__5fc$object *, struct _jc_object *);
extern void _jc_polyglot_ext_param_types_MuPClass__5fc$method$_init$cf03b0c68237e0b4(_jc_env *, struct _jc_polyglot_ext_param_types_MuPClass__5fc$object *, struct _jc_object *, struct _jc_polyglot_util_Position$object *);

// Virtual methods
extern void _jc_polyglot_ext_param_types_MuPClass__5fc$method$addFormal$1212ffd6c14aab80(_jc_env *, struct _jc_polyglot_ext_param_types_MuPClass__5fc$object *, struct _jc_object *);
extern struct _jc_object *_jc_polyglot_ext_param_types_MuPClass__5fc$method$clazz$644b1286232a7f60(_jc_env *, struct _jc_polyglot_ext_param_types_MuPClass__5fc$object *);
extern void _jc_polyglot_ext_param_types_MuPClass__5fc$method$clazz$89e68db27d13828c(_jc_env *, struct _jc_polyglot_ext_param_types_MuPClass__5fc$object *, struct _jc_object *);
extern struct _jc_object *_jc_polyglot_ext_param_types_MuPClass__5fc$method$formals$a539547bab4f4a88(_jc_env *, struct _jc_polyglot_ext_param_types_MuPClass__5fc$object *);
extern void _jc_polyglot_ext_param_types_MuPClass__5fc$method$formals$c353c652b5be31d8(_jc_env *, struct _jc_polyglot_ext_param_types_MuPClass__5fc$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_polyglot_ext_param_types_MuPClass__5fc$method_info$addFormal$1212ffd6c14aab80;
extern _jc_method _jc_polyglot_ext_param_types_MuPClass__5fc$method_info$clazz$644b1286232a7f60;
extern _jc_method _jc_polyglot_ext_param_types_MuPClass__5fc$method_info$clazz$89e68db27d13828c;
extern _jc_method _jc_polyglot_ext_param_types_MuPClass__5fc$method_info$formals$a539547bab4f4a88;
extern _jc_method _jc_polyglot_ext_param_types_MuPClass__5fc$method_info$formals$c353c652b5be31d8;

// Static methods
extern struct _jc_java_lang_Class$object *_jc_polyglot_ext_param_types_MuPClass__5fc$method$class__24$57cd45dca0be1678(_jc_env *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_polyglot_ext_param_types_MuPClass__5fc$vmethods {
	void	(*addFormal$1212ffd6c14aab80)(_jc_env *, struct _jc_polyglot_ext_param_types_MuPClass__5fc$object *, struct _jc_object *);
	struct _jc_object	*(*clazz$644b1286232a7f60)(_jc_env *, struct _jc_polyglot_ext_param_types_MuPClass__5fc$object *);
	void	(*clazz$89e68db27d13828c)(_jc_env *, struct _jc_polyglot_ext_param_types_MuPClass__5fc$object *, struct _jc_object *);
	struct _jc_object	*(*formals$a539547bab4f4a88)(_jc_env *, struct _jc_polyglot_ext_param_types_MuPClass__5fc$object *);
	void	(*formals$c353c652b5be31d8)(_jc_env *, struct _jc_polyglot_ext_param_types_MuPClass__5fc$object *, struct _jc_object *);
};

// Vtable
struct _jc_polyglot_ext_param_types_MuPClass__5fc$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_ext_jl_types_TypeObject__5fc$vmethods	polyglot_ext_jl_types_TypeObject__5fc;
	_jc_polyglot_ext_param_types_PClass__5fc$vmethods	polyglot_ext_param_types_PClass__5fc;
	_jc_polyglot_ext_param_types_MuPClass__5fc$vmethods	polyglot_ext_param_types_MuPClass__5fc;
};

// Vtype
struct _jc_polyglot_ext_param_types_MuPClass__5fc$vtype {
	_jc_type			type;
	_jc_polyglot_ext_param_types_MuPClass__5fc$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_ext_param_types_MuPClass__5fc$sub_refs {
	struct _jc_object	*formals;
	struct _jc_object	*clazz;
};

// Reference instance fields (object)
struct _jc_polyglot_ext_param_types_MuPClass__5fc$refs {
    _jc_polyglot_ext_param_types_MuPClass__5fc$sub_refs	polyglot_ext_param_types_MuPClass__5fc;
    _jc_polyglot_ext_param_types_PClass__5fc$sub_refs	polyglot_ext_param_types_PClass__5fc;
    _jc_polyglot_ext_jl_types_TypeObject__5fc$sub_refs	polyglot_ext_jl_types_TypeObject__5fc;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_ext_param_types_MuPClass__5fc$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_ext_param_types_MuPClass__5fc$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_ext_jl_types_TypeObject__5fc$sub_nonrefs	polyglot_ext_jl_types_TypeObject__5fc;
    _jc_polyglot_ext_param_types_PClass__5fc$sub_nonrefs	polyglot_ext_param_types_PClass__5fc;
    _jc_polyglot_ext_param_types_MuPClass__5fc$sub_nonrefs	polyglot_ext_param_types_MuPClass__5fc;
};

// Object instance structure
struct _jc_polyglot_ext_param_types_MuPClass__5fc$object {
	_jc_polyglot_ext_param_types_MuPClass__5fc$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_ext_param_types_MuPClass__5fc$vtype	*vtype;
	_jc_polyglot_ext_param_types_MuPClass__5fc$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_ext_param_types_MuPClass__5fc$vtype _jc_polyglot_ext_param_types_MuPClass__5fc$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_ext_param_types_MuPClass__5fc, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_ext_param_types_MuPClass__5fc$class_object;

#endif	/* _JC_polyglot_ext_param_types_MuPClass__5fc_H_ */

==> jc-1.4.6.tar.gz: polyglot/ext/param/types/MuPClass__5fc.h <==
// public class polyglot.ext.param.types.MuPClass_c

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class d130bd574566704f polyglot_ext_jl_types_TypeObject__5fc
// @dep_class 16b1510ff9395e7b polyglot_ext_param_types_MuPClass__5fc
// @dep_class 1396827e5adf47cf polyglot_ext_param_types_PClass__5fc

// header file dependencies
// @dep_header polyglot_ext_param_types_PClass__5fc

#include "polyglot/ext/param/types/PClass__5fc.h"

#ifndef _JC_polyglot_ext_param_types_MuPClass__5fc_H_
#define _JC_polyglot_ext_param_types_MuPClass__5fc_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_List$object;
struct _jc_polyglot_ext_param_types_Param$object;
struct _jc_polyglot_types_ClassType$object;
struct _jc_polyglot_types_TypeSystem$object;
struct _jc_polyglot_util_Position$object;

// Typedefs
typedef struct _jc_polyglot_ext_param_types_MuPClass__5fc$sub_refs	_jc_polyglot_ext_param_types_MuPClass__5fc$sub_refs;
typedef struct _jc_polyglot_ext_param_types_MuPClass__5fc$sub_nonrefs	_jc_polyglot_ext_param_types_MuPClass__5fc$sub_nonrefs;
typedef struct _jc_polyglot_ext_param_types_MuPClass__5fc$refs	_jc_polyglot_ext_param_types_MuPClass__5fc$refs;
typedef struct _jc_polyglot_ext_param_types_MuPClass__5fc$nonrefs	_jc_polyglot_ext_param_types_MuPClass__5fc$nonrefs;
typedef struct _jc_polyglot_ext_param_types_MuPClass__5fc$object	_jc_polyglot_ext_param_types_MuPClass__5fc$object;

typedef struct _jc_polyglot_ext_param_types_MuPClass__5fc$fields_struct	_jc_polyglot_ext_param_types_MuPClass__5fc$fields_struct;
typedef const struct _jc_polyglot_ext_param_types_MuPClass__5fc$vmethods	_jc_polyglot_ext_param_types_MuPClass__5fc$vmethods;
typedef const struct _jc_polyglot_ext_param_types_MuPClass__5fc$vtable	_jc_polyglot_ext_param_types_MuPClass__5fc$vtable;
typedef const struct _jc_polyglot_ext_param_types_MuPClass__5fc$vtype	_jc_polyglot_ext_param_types_MuPClass__5fc$vtype;

// Class fields structure
struct _jc_polyglot_ext_param_types_MuPClass__5fc$fields_struct {
	struct _jc_java_lang_Class$object	*class__24polyglot__24ext__24param__24types__24Param;
};
extern _jc_polyglot_ext_param_types_MuPClass__5fc$fields_struct _jc_polyglot_ext_param_types_MuPClass__5fc$class_fields;

// Constructors
extern void _jc_polyglot_ext_param_types_MuPClass__5fc$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_polyglot_ext_param_types_MuPClass__5fc$object *) _JC_JCNI_ATTR;
extern void _jc_polyglot_ext_param_types_MuPClass__5fc$method$_init$964314195388e7c0(_jc_env *, struct _jc_polyglot_ext_param_types_MuPClass__5fc$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_polyglot_ext_param_types_MuPClass__5fc$method$_init$cf03b0c68237e0b4(_jc_env *, struct _jc_polyglot_ext_param_types_MuPClass__5fc$object *, struct _jc_object *, struct _jc_polyglot_util_Position$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_polyglot_ext_param_types_MuPClass__5fc$method$addFormal$1212ffd6c14aab80(_jc_env *, struct _jc_polyglot_ext_param_types_MuPClass__5fc$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_polyglot_ext_param_types_MuPClass__5fc$method$clazz$644b1286232a7f60(_jc_env *, struct _jc_polyglot_ext_param_types_MuPClass__5fc$object *) _JC_JCNI_ATTR;
extern void _jc_polyglot_ext_param_types_MuPClass__5fc$method$clazz$89e68db27d13828c(_jc_env *, struct _jc_polyglot_ext_param_types_MuPClass__5fc$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_polyglot_ext_param_types_MuPClass__5fc$method$formals$a539547bab4f4a88(_jc_env *, struct _jc_polyglot_ext_param_types_MuPClass__5fc$object *) _JC_JCNI_ATTR;
extern void _jc_polyglot_ext_param_types_MuPClass__5fc$method$formals$c353c652b5be31d8(_jc_env *, struct _jc_polyglot_ext_param_types_MuPClass__5fc$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_polyglot_ext_param_types_MuPClass__5fc$method_info$addFormal$1212ffd6c14aab80;
extern _jc_method _jc_polyglot_ext_param_types_MuPClass__5fc$method_info$clazz$644b1286232a7f60;
extern _jc_method _jc_polyglot_ext_param_types_MuPClass__5fc$method_info$clazz$89e68db27d13828c;
extern _jc_method _jc_polyglot_ext_param_types_MuPClass__5fc$method_info$formals$a539547bab4f4a88;
extern _jc_method _jc_polyglot_ext_param_types_MuPClass__5fc$method_info$formals$c353c652b5be31d8;

// Static methods
extern struct _jc_java_lang_Class$object *_jc_polyglot_ext_param_types_MuPClass__5fc$method$class__24$57cd45dca0be1678(_jc_env *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_polyglot_ext_param_types_MuPClass__5fc$vmethods {
	void	(*addFormal$1212ffd6c14aab80)(_jc_env *, struct _jc_polyglot_ext_param_types_MuPClass__5fc$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*clazz$644b1286232a7f60)(_jc_env *, struct _jc_polyglot_ext_param_types_MuPClass__5fc$object *) _JC_JCNI_ATTR;
	void	(*clazz$89e68db27d13828c)(_jc_env *, struct _jc_polyglot_ext_param_types_MuPClass__5fc$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*formals$a539547bab4f4a88)(_jc_env *, struct _jc_polyglot_ext_param_types_MuPClass__5fc$object *) _JC_JCNI_ATTR;
	void	(*formals$c353c652b5be31d8)(_jc_env *, struct _jc_polyglot_ext_param_types_MuPClass__5fc$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_polyglot_ext_param_types_MuPClass__5fc$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_ext_jl_types_TypeObject__5fc$vmethods	polyglot_ext_jl_types_TypeObject__5fc;
	_jc_polyglot_ext_param_types_PClass__5fc$vmethods	polyglot_ext_param_types_PClass__5fc;
	_jc_polyglot_ext_param_types_MuPClass__5fc$vmethods	polyglot_ext_param_types_MuPClass__5fc;
};

// Vtype
struct _jc_polyglot_ext_param_types_MuPClass__5fc$vtype {
	_jc_type			type;
	_jc_polyglot_ext_param_types_MuPClass__5fc$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_ext_param_types_MuPClass__5fc$sub_refs {
	struct _jc_object	*formals;
	struct _jc_object	*clazz;
};

// Reference instance fields (object)
struct _jc_polyglot_ext_param_types_MuPClass__5fc$refs {
    _jc_polyglot_ext_param_types_MuPClass__5fc$sub_refs	polyglot_ext_param_types_MuPClass__5fc;
    _jc_polyglot_ext_param_types_PClass__5fc$sub_refs	polyglot_ext_param_types_PClass__5fc;
    _jc_polyglot_ext_jl_types_TypeObject__5fc$sub_refs	polyglot_ext_jl_types_TypeObject__5fc;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_ext_param_types_MuPClass__5fc$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_ext_param_types_MuPClass__5fc$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_ext_jl_types_TypeObject__5fc$sub_nonrefs	polyglot_ext_jl_types_TypeObject__5fc;
    _jc_polyglot_ext_param_types_PClass__5fc$sub_nonrefs	polyglot_ext_param_types_PClass__5fc;
    _jc_polyglot_ext_param_types_MuPClass__5fc$sub_nonrefs	polyglot_ext_param_types_MuPClass__5fc;
};

// Object instance structure
struct _jc_polyglot_ext_param_types_MuPClass__5fc$object {
	_jc_polyglot_ext_param_types_MuPClass__5fc$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_ext_param_types_MuPClass__5fc$vtype	*vtype;
	_jc_polyglot_ext_param_types_MuPClass__5fc$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_ext_param_types_MuPClass__5fc$vtype _jc_polyglot_ext_param_types_MuPClass__5fc$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_ext_param_types_MuPClass__5fc, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_ext_param_types_MuPClass__5fc$class_object;

#endif	/* _JC_polyglot_ext_param_types_MuPClass__5fc_H_ */
